==> vertx-stack-docs-3.3.3-docs.zip: ceylondoc/vertx-sql/.resources/index.js <==
var index = [
{'name': 'io.vertx.ceylon.sql', 'type': 'package', 'url': 'index.html#section-package', 'doc': '', 'tags': [],'icons': ['icon-package']},
{'name': 'ResultSet.toJson', 'type': 'function', 'url': 'ResultSet.type.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'ResultSet', 'type': 'class', 'url': 'ResultSet.type.html', 'doc': '<p>Represents the results of a SQL query.\n<p>\nI', 'tags': [],'icons': ['icon-class']},
{'name': 'resultSet.fromJson', 'type': 'function', 'url': 'resultSet.object.html#fromJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toCeylon.convert', 'type': 'function', 'url': 'resultSet.toCeylon.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toCeylon', 'type': 'object', 'url': 'resultSet.toCeylon.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'resultSet.toCeylon', 'type': 'value', 'url': 'resultSet.object.html#toCeylon', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'resultSet.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'resultSet.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'resultSet.toJava', 'type': 'value', 'url': 'resultSet.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'resultSet.toJson', 'type': 'function', 'url': 'resultSet.object.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'resultSet', 'type': 'object', 'url': 'resultSet.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'resultSet', 'type': 'value', 'url': 'index.html#resultSet', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'TransactionIsolation', 'type': 'class', 'url': 'TransactionIsolation.type.html', 'doc': '<p>Represents a Transaction Isolation Level</p>', 'tags': [],'icons': ['icon-class', 'icon-decoration-abstract', 'icon-decoration-enumerated']},
{'name': 'read_uncommitted', 'type': 'object', 'url': 'read_uncommitted.object.html', 'doc': '<p>Implements dirty read, or isolation level 0 locking, which means that no shared locks are issued and no exclusive\nlocks…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'read_uncommitted', 'type': 'value', 'url': 'index.html#read_uncommitted', 'doc': '<p>Implements dirty read, or isolation level 0 locking, which means that no shared locks are issued and no exclusive\nlocks…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'read_committed', 'type': 'object', 'url': 'read_committed.object.html', 'doc': '<p>Specifies that shared locks are held while the data is being read to avoid dirty reads, but the data can be changed…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'read_committed', 'type': 'value', 'url': 'index.html#read_committed', 'doc': '<p>Specifies that shared locks are held while the data is being read to avoid dirty reads, but the data can be changed…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'repeatable_read', 'type': 'object', 'url': 'repeatable_read.object.html', 'doc': '<p>Locks are placed on all data that is used in a query, preventing other users from updating the data, but new\nphantom…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'repeatable_read', 'type': 'value', 'url': 'index.html#repeatable_read', 'doc': '<p>Locks are placed on all data that is used in a query, preventing other users from updating the data, but new\nphantom…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'serializable', 'type': 'object', 'url': 'serializable.object.html', 'doc': '<p>Places a range lock on the data set, preventing other users from updating or inserting rows into the data set until\nthe…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'serializable', 'type': 'value', 'url': 'index.html#serializable', 'doc': '<p>Places a range lock on the data set, preventing other users from updating or inserting rows into the data set until\nthe…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'none', 'type': 'object', 'url': 'none.object.html', 'doc': '<p>For engines that support it, none isolation means that each statement would essentially be its own transaction.</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'none', 'type': 'value', 'url': 'index.html#none', 'doc': '<p>For engines that support it, none isolation means that each statement would essentially be its own transaction.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'transactionIsolation.toString', 'type': 'function', 'url': 'transactionIsolation.object.html#toString', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'transactionIsolation.fromString', 'type': 'function', 'url': 'transactionIsolation.object.html#fromString', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'transactionIsolation.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'transactionIsolation.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'transactionIsolation.toJava', 'type': 'value', 'url': 'transactionIsolation.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toCeylon.convert', 'type': 'function', 'url': 'transactionIsolation.toCeylon.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toCeylon', 'type': 'object', 'url': 'transactionIsolation.toCeylon.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'transactionIsolation.toCeylon', 'type': 'value', 'url': 'transactionIsolation.object.html#toCeylon', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'transactionIsolation', 'type': 'object', 'url': 'transactionIsolation.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'transactionIsolation', 'type': 'value', 'url': 'index.html#transactionIsolation', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'UpdateResult.toJson', 'type': 'function', 'url': 'UpdateResult.type.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'UpdateResult', 'type': 'class', 'url': 'UpdateResult.type.html', 'doc': '<p>Represents the result of an update/insert/delete operation on the database.\n<p>\nT', 'tags': [],'icons': ['icon-class']},
{'name': 'updateResult.fromJson', 'type': 'function', 'url': 'updateResult.object.html#fromJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toCeylon.convert', 'type': 'function', 'url': 'updateResult.toCeylon.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toCeylon', 'type': 'object', 'url': 'updateResult.toCeylon.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'updateResult.toCeylon', 'type': 'value', 'url': 'updateResult.object.html#toCeylon', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'updateResult.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'updateResult.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'updateResult.toJava', 'type': 'value', 'url': 'updateResult.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'updateResult.toJson', 'type': 'function', 'url': 'updateResult.object.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'updateResult', 'type': 'object', 'url': 'updateResult.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'updateResult', 'type': 'value', 'url': 'index.html#updateResult', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.update', 'type': 'function', 'url': 'SQLConnection.type.html#update', 'doc': '<p>Executes the given SQL statement which may be an <code>INSERT</code>, <code>UPDATE</code>, or <code>DELETE</code>\nstatement.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.execute', 'type': 'function', 'url': 'SQLConnection.type.html#execute', 'doc': '<p>Executes the given SQL statement</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.close', 'type': 'function', 'url': 'SQLConnection.type.html#close', 'doc': '<p>Closes the connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.close', 'type': 'function', 'url': 'SQLConnection.type.html#close', 'doc': '<p>Closes the connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.close', 'type': 'function', 'url': 'SQLConnection.type.html#close', 'doc': '<p>Closes the connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.query', 'type': 'function', 'url': 'SQLConnection.type.html#query', 'doc': '<p>Executes the given SQL <code>SELECT</code> statement which returns the results of the query.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.call', 'type': 'function', 'url': 'SQLConnection.type.html#call', 'doc': '<p>Calls the given SQL <code>PROCEDURE</code> which returns the result from the procedure.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.batch', 'type': 'function', 'url': 'SQLConnection.type.html#batch', 'doc': '<p>Batch simple SQL strings and execute the batch where the async result contains a array of Integers.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.commit', 'type': 'function', 'url': 'SQLConnection.type.html#commit', 'doc': '<p>Commits all changes made since the previous commit/rollback.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.rollback', 'type': 'function', 'url': 'SQLConnection.type.html#rollback', 'doc': '<p>Rolls back all changes made since the previous commit/rollback.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.setQueryTimeout', 'type': 'function', 'url': 'SQLConnection.type.html#setQueryTimeout', 'doc': '<p>Sets a connection wide query timeout.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.setAutoCommit', 'type': 'function', 'url': 'SQLConnection.type.html#setAutoCommit', 'doc': '<p>Sets the auto commit flag for this connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.queryWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#queryWithParams', 'doc': '<p>Executes the given SQL <code>SELECT</code> prepared statement which returns the results of the query.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.updateWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#updateWithParams', 'doc': '<p>Executes the given prepared statement which may be an <code>INSERT</code>, <code>UPDATE</code>, or <code>DELETE</code>\nstatement with the given parameters</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.callWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#callWithParams', 'doc': '<p>Calls the given SQL <code>PROCEDURE</code> which returns the result from the procedure.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.batchWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#batchWithParams', 'doc': '<p>Batch a prepared statement with all entries from the args list.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.batchCallableWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#batchCallableWithParams', 'doc': '<p>Batch a callable statement with all entries from the args list.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.setTransactionIsolation', 'type': 'function', 'url': 'SQLConnection.type.html#setTransactionIsolation', 'doc': '<p>Attempts to change the transaction isolation level for this Connection object to the one given.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.getTransactionIsolation', 'type': 'function', 'url': 'SQLConnection.type.html#getTransactionIsolation', 'doc': '<p>Attempts to return the transaction isolation level for this Connection object to the one given.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection', 'type': 'class', 'url': 'SQLConnection.type.html', 'doc': '<p>Represents a connection to a SQL database</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'io.vertx.ceylon.sql', 'type': 'module', 'url': 'index.html', 'doc': '', 'tags': [],'icons': ['icon-module']}];
var tagIndex = [
];

==> vertx-stack-docs-3.4.1-docs.zip: ceylondoc/vertx-sql/.resources/index.js <==
var index = [
{'name': 'io.vertx.ceylon.sql', 'type': 'package', 'url': 'index.html#section-package', 'doc': '', 'tags': [],'icons': ['icon-package']},
{'name': 'ResultSet.toJson', 'type': 'function', 'url': 'ResultSet.type.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'ResultSet', 'type': 'class', 'url': 'ResultSet.type.html', 'doc': '<p>Represents the results of a SQL query.\n<p>\nI', 'tags': [],'icons': ['icon-class']},
{'name': 'resultSet.fromJson', 'type': 'function', 'url': 'resultSet.object.html#fromJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toCeylon.convert', 'type': 'function', 'url': 'resultSet.toCeylon.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toCeylon', 'type': 'object', 'url': 'resultSet.toCeylon.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'resultSet.toCeylon', 'type': 'value', 'url': 'resultSet.object.html#toCeylon', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'resultSet.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'resultSet.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'resultSet.toJava', 'type': 'value', 'url': 'resultSet.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'resultSet.toJson', 'type': 'function', 'url': 'resultSet.object.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'resultSet', 'type': 'object', 'url': 'resultSet.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'resultSet', 'type': 'value', 'url': 'index.html#resultSet', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'TransactionIsolation', 'type': 'class', 'url': 'TransactionIsolation.type.html', 'doc': '<p>Represents a Transaction Isolation Level</p>', 'tags': [],'icons': ['icon-class', 'icon-decoration-abstract', 'icon-decoration-enumerated']},
{'name': 'read_uncommitted', 'type': 'object', 'url': 'read_uncommitted.object.html', 'doc': '<p>Implements dirty read, or isolation level 0 locking, which means that no shared locks are issued and no exclusive\nlocks…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'read_uncommitted', 'type': 'value', 'url': 'index.html#read_uncommitted', 'doc': '<p>Implements dirty read, or isolation level 0 locking, which means that no shared locks are issued and no exclusive\nlocks…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'read_committed', 'type': 'object', 'url': 'read_committed.object.html', 'doc': '<p>Specifies that shared locks are held while the data is being read to avoid dirty reads, but the data can be changed…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'read_committed', 'type': 'value', 'url': 'index.html#read_committed', 'doc': '<p>Specifies that shared locks are held while the data is being read to avoid dirty reads, but the data can be changed…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'repeatable_read', 'type': 'object', 'url': 'repeatable_read.object.html', 'doc': '<p>Locks are placed on all data that is used in a query, preventing other users from updating the data, but new\nphantom…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'repeatable_read', 'type': 'value', 'url': 'index.html#repeatable_read', 'doc': '<p>Locks are placed on all data that is used in a query, preventing other users from updating the data, but new\nphantom…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'serializable', 'type': 'object', 'url': 'serializable.object.html', 'doc': '<p>Places a range lock on the data set, preventing other users from updating or inserting rows into the data set until\nthe…</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'serializable', 'type': 'value', 'url': 'index.html#serializable', 'doc': '<p>Places a range lock on the data set, preventing other users from updating or inserting rows into the data set until\nthe…</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'none', 'type': 'object', 'url': 'none.object.html', 'doc': '<p>For engines that support it, none isolation means that each statement would essentially be its own transaction.</p>', 'tags': [],'icons': ['icon-object']},
{'name': 'none', 'type': 'value', 'url': 'index.html#none', 'doc': '<p>For engines that support it, none isolation means that each statement would essentially be its own transaction.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'transactionIsolation.toString', 'type': 'function', 'url': 'transactionIsolation.object.html#toString', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'transactionIsolation.fromString', 'type': 'function', 'url': 'transactionIsolation.object.html#fromString', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'transactionIsolation.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'transactionIsolation.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'transactionIsolation.toJava', 'type': 'value', 'url': 'transactionIsolation.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toCeylon.convert', 'type': 'function', 'url': 'transactionIsolation.toCeylon.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toCeylon', 'type': 'object', 'url': 'transactionIsolation.toCeylon.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'transactionIsolation.toCeylon', 'type': 'value', 'url': 'transactionIsolation.object.html#toCeylon', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'transactionIsolation', 'type': 'object', 'url': 'transactionIsolation.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'transactionIsolation', 'type': 'value', 'url': 'index.html#transactionIsolation', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'UpdateResult.toJson', 'type': 'function', 'url': 'UpdateResult.type.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'UpdateResult', 'type': 'class', 'url': 'UpdateResult.type.html', 'doc': '<p>Represents the result of an update/insert/delete operation on the database.\n<p>\nT', 'tags': [],'icons': ['icon-class']},
{'name': 'updateResult.fromJson', 'type': 'function', 'url': 'updateResult.object.html#fromJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toCeylon.convert', 'type': 'function', 'url': 'updateResult.toCeylon.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toCeylon', 'type': 'object', 'url': 'updateResult.toCeylon.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'updateResult.toCeylon', 'type': 'value', 'url': 'updateResult.object.html#toCeylon', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'toJava.convert', 'type': 'function', 'url': 'updateResult.toJava.object.html#convert', 'doc': '', 'tags': [],'icons': ['icon-shared-member', 'icon-decoration-impl']},
{'name': 'toJava', 'type': 'object', 'url': 'updateResult.toJava.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'updateResult.toJava', 'type': 'value', 'url': 'updateResult.object.html#toJava', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'updateResult.toJson', 'type': 'function', 'url': 'updateResult.object.html#toJson', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'updateResult', 'type': 'object', 'url': 'updateResult.object.html', 'doc': '', 'tags': [],'icons': ['icon-object']},
{'name': 'updateResult', 'type': 'value', 'url': 'index.html#updateResult', 'doc': '', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.update', 'type': 'function', 'url': 'SQLConnection.type.html#update', 'doc': '<p>Executes the given SQL statement which may be an <code>INSERT</code>, <code>UPDATE</code>, or <code>DELETE</code>\nstatement.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.execute', 'type': 'function', 'url': 'SQLConnection.type.html#execute', 'doc': '<p>Executes the given SQL statement</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.close', 'type': 'function', 'url': 'SQLConnection.type.html#close', 'doc': '<p>Closes the connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.close', 'type': 'function', 'url': 'SQLConnection.type.html#close', 'doc': '<p>Closes the connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.close', 'type': 'function', 'url': 'SQLConnection.type.html#close', 'doc': '<p>Closes the connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.query', 'type': 'function', 'url': 'SQLConnection.type.html#query', 'doc': '<p>Executes the given SQL <code>SELECT</code> statement which returns the results of the query.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.call', 'type': 'function', 'url': 'SQLConnection.type.html#call', 'doc': '<p>Calls the given SQL <code>PROCEDURE</code> which returns the result from the procedure.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.commit', 'type': 'function', 'url': 'SQLConnection.type.html#commit', 'doc': '<p>Commits all changes made since the previous commit/rollback.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.queryStreamWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#queryStreamWithParams', 'doc': '<p>Executes the given SQL <code>SELECT</code> statement which returns the results of the query as a read stream.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.queryWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#queryWithParams', 'doc': '<p>Executes the given SQL <code>SELECT</code> prepared statement which returns the results of the query.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.queryStream', 'type': 'function', 'url': 'SQLConnection.type.html#queryStream', 'doc': '<p>Executes the given SQL <code>SELECT</code> statement which returns the results of the query as a read stream.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.setAutoCommit', 'type': 'function', 'url': 'SQLConnection.type.html#setAutoCommit', 'doc': '<p>Sets the auto commit flag for this connection.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.updateWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#updateWithParams', 'doc': '<p>Executes the given prepared statement which may be an <code>INSERT</code>, <code>UPDATE</code>, or <code>DELETE</code>\nstatement with the given parameters</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.callWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#callWithParams', 'doc': '<p>Calls the given SQL <code>PROCEDURE</code> which returns the result from the procedure.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.batchWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#batchWithParams', 'doc': '<p>Batch a prepared statement with all entries from the args list.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.batchCallableWithParams', 'type': 'function', 'url': 'SQLConnection.type.html#batchCallableWithParams', 'doc': '<p>Batch a callable statement with all entries from the args list.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.setTransactionIsolation', 'type': 'function', 'url': 'SQLConnection.type.html#setTransactionIsolation', 'doc': '<p>Attempts to change the transaction isolation level for this Connection object to the one given.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.getTransactionIsolation', 'type': 'function', 'url': 'SQLConnection.type.html#getTransactionIsolation', 'doc': '<p>Attempts to return the transaction isolation level for this Connection object to the one given.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.batch', 'type': 'function', 'url': 'SQLConnection.type.html#batch', 'doc': '<p>Batch simple SQL strings and execute the batch where the async result contains a array of Integers.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.rollback', 'type': 'function', 'url': 'SQLConnection.type.html#rollback', 'doc': '<p>Rolls back all changes made since the previous commit/rollback.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection.setQueryTimeout', 'type': 'function', 'url': 'SQLConnection.type.html#setQueryTimeout', 'doc': '<p>Sets a connection wide query timeout.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLConnection', 'type': 'class', 'url': 'SQLConnection.type.html', 'doc': '<p>Represents a connection to a SQL database</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'SQLRowStream.resume', 'type': 'function', 'url': 'SQLRowStream.type.html#resume', 'doc': '<p>Resume reading. I</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.close', 'type': 'function', 'url': 'SQLRowStream.type.html#close', 'doc': '<p>Closes the stream/underlying cursor(s).</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.close', 'type': 'function', 'url': 'SQLRowStream.type.html#close', 'doc': '<p>Closes the stream/underlying cursor(s).</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.close', 'type': 'function', 'url': 'SQLRowStream.type.html#close', 'doc': '<p>Closes the stream/underlying cursor(s).</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.handler', 'type': 'function', 'url': 'SQLRowStream.type.html#handler', 'doc': '<p>Set a data handler.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.column', 'type': 'function', 'url': 'SQLRowStream.type.html#column', 'doc': '<p>Will convert the column name to the json array index.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.moreResults', 'type': 'function', 'url': 'SQLRowStream.type.html#moreResults', 'doc': '<p>Request for more results if available</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.resultSetClosedHandler', 'type': 'function', 'url': 'SQLRowStream.type.html#resultSetClosedHandler', 'doc': '<p>Event handler when a resultset is closed.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.exceptionHandler', 'type': 'function', 'url': 'SQLRowStream.type.html#exceptionHandler', 'doc': '<p>Set an exception handler.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.pause', 'type': 'function', 'url': 'SQLRowStream.type.html#pause', 'doc': '<p>Pause the <code>ReadSupport</code>. W</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream.endHandler', 'type': 'function', 'url': 'SQLRowStream.type.html#endHandler', 'doc': '<p>Set an end handler.</p>', 'tags': [],'icons': ['icon-shared-member']},
{'name': 'SQLRowStream', 'type': 'class', 'url': 'SQLRowStream.type.html', 'doc': '<p>A ReadStream of Rows from the underlying RDBMS. T</p>', 'tags': [],'icons': ['icon-class']},
{'name': 'io.vertx.ceylon.sql', 'type': 'module', 'url': 'index.html', 'doc': '', 'tags': [],'icons': ['icon-module']}];
var tagIndex = [
];
